/*
 * Copyright 2019 Confluent Inc.
 *
 * Licensed under the Confluent Community License (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of the
 * License at
 *
 * http://www.confluent.io/confluent-community-license
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

package io.confluent.kafka.secretregistry.storage;

import com.fasterxml.jackson.annotation.JsonProperty;

import javax.validation.constraints.Min;

import org.hibernate.validator.constraints.NotEmpty;

public abstract class SecretRegistryKey implements Comparable<SecretRegistryKey> {

  @Min(0)
  protected int magicByte;
  @NotEmpty
  protected SecretRegistryKeyType keyType;

  public SecretRegistryKey(@JsonProperty("keytype") SecretRegistryKeyType keyType) {
    this.keyType = keyType;
  }

  @JsonProperty("magic")
  public int getMagicByte() {
    return this.magicByte;
  }

  @JsonProperty("magic")
  public void setMagicByte(int magicByte) {
    this.magicByte = magicByte;
  }

  @JsonProperty("keytype")
  public SecretRegistryKeyType getKeyType() {
    return this.keyType;
  }

  @JsonProperty("keytype")
  public void setKeyType(SecretRegistryKeyType keyType) {
    this.keyType = keyType;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }

    SecretRegistryKey that = (SecretRegistryKey) o;

    if (this.magicByte != that.magicByte) {
      return false;
    }
    if (!this.keyType.equals(that.keyType)) {
      return false;
    }
    return true;
  }

  @Override
  public int hashCode() {
    int result = 31 * this.magicByte;
    result = 31 * result + this.keyType.hashCode();
    return result;
  }

  @Override
  public int compareTo(SecretRegistryKey otherKey) {
    return this.keyType.compareTo(otherKey.keyType);
  }
}
